<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>FAQ</name>
    <message>
        <location filename="../FAQInit.js" line="+2"/>
        <source>FA&amp;Qs (online)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Najczęstsze pytania</translation>
    </message>
</context>
</TS>
